@@ -18,7 +18,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_rename.c,v 1.16 2003/08/29 22:00:04 rees Exp $");
+    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_rename.c,v 1.16.2.2 2004/10/18 17:43:53 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -46,7 +46,8 @@ afsrename(struct vcache *aodp, char *aname1, struct vcache *andp,
     struct dcache *tdc1, *tdc2;
     struct AFSFetchStatus OutOldDirStatus, OutNewDirStatus;
     struct AFSVolSync tsync;
-    XSTATS_DECLS AFS_STATCNT(afs_rename);
+    XSTATS_DECLS;
+    AFS_STATCNT(afs_rename);
     afs_Trace4(afs_iclSetp, CM_TRACE_RENAME, ICL_TYPE_POINTER, aodp,
 	       ICL_TYPE_STRING, aname1, ICL_TYPE_POINTER, andp,
 	       ICL_TYPE_STRING, aname2);
@@ -145,7 +146,7 @@ afsrename(struct vcache *aodp, char *aname1, struct vcache *andp,
     }
 
     if (code == 0)
-	code = afs_dir_Lookup(&tdc1->f.inode, aname1, &fileFid.Fid);
+	code = afs_dir_Lookup(&tdc1->f, aname1, &fileFid.Fid);
     if (code) {
 	if (tdc1) {
 	    ReleaseWriteLock(&tdc1->lock);
@@ -204,38 +205,38 @@ afsrename(struct vcache *aodp, char *aname1, struct vcache *andp,
 	    if (!doLocally) {
 		if (tdc1) {
 		    ZapDCE(tdc1);
-		    DZap(&tdc1->f.inode);
+		    DZap(&tdc1->f);
 		}
 		if (tdc2) {
 		    ZapDCE(tdc2);
-		    DZap(&tdc2->f.inode);
+		    DZap(&tdc2->f);
 		}
 	    }
 	}
 	/* now really do the work */
 	if (doLocally) {
 	    /* first lookup the fid of the dude we're moving */
-	    code = afs_dir_Lookup(&tdc1->f.inode, aname1, &fileFid.Fid);
+	    code = afs_dir_Lookup(&tdc1->f, aname1, &fileFid.Fid);
 	    if (code == 0) {
 		/* delete the source */
-		code = afs_dir_Delete(&tdc1->f.inode, aname1);
+		code = afs_dir_Delete(&tdc1->f, aname1);
 	    }
 	    /* first see if target is there */
 	    if (code == 0
-		&& afs_dir_Lookup(&tdc2->f.inode, aname2,
+		&& afs_dir_Lookup(&tdc2->f, aname2,
 				  &unlinkFid.Fid) == 0) {
 		/* target already exists, and will be unlinked by server */
-		code = afs_dir_Delete(&tdc2->f.inode, aname2);
+		code = afs_dir_Delete(&tdc2->f, aname2);
 	    }
 	    if (code == 0) {
-		code = afs_dir_Create(&tdc2->f.inode, aname2, &fileFid.Fid);
+		code = afs_dir_Create(&tdc2->f, aname2, &fileFid.Fid);
 	    }
 	    if (code != 0) {
 		ZapDCE(tdc1);
-		DZap(&tdc1->f.inode);
+		DZap(&tdc1->f);
 		if (!oneDir) {
 		    ZapDCE(tdc2);
-		    DZap(&tdc2->f.inode);
+		    DZap(&tdc2->f);
 		}
 	    }
 	}
@@ -338,7 +339,7 @@ afsrename(struct vcache *aodp, char *aname1, struct vcache *andp,
 	    if (tdc1) {
 		ObtainWriteLock(&tdc1->lock, 648);
 		ZapDCE(tdc1);	/* mark as unknown */
-		DZap(&tdc1->f.inode);
+		DZap(&tdc1->f);
 		ReleaseWriteLock(&tdc1->lock);
 		afs_PutDCache(tdc1);	/* put it back */
 	    }
@@ -370,11 +371,11 @@ afs_rename(fndp, tndp)
 #else /* AFS_OSF_ENV */
 #if defined(AFS_SGI_ENV)
 afs_rename(OSI_VC_ARG(aodp), aname1, andp, aname2, npnp, acred)
-     struct pathname *npnp;
+    struct pathname *npnp;
 #else
 afs_rename(OSI_VC_ARG(aodp), aname1, andp, aname2, acred)
 #endif
-    OSI_VC_DECL(aodp);
+     OSI_VC_DECL(aodp);
      struct vcache *andp;
      char *aname1, *aname2;
      struct AFS_UCRED *acred;
@@ -384,9 +385,9 @@ afs_rename(OSI_VC_ARG(aodp), aname1, andp, aname2, acred)
     struct afs_fakestat_state ofakestate;
     struct afs_fakestat_state nfakestate;
     struct vrequest treq;
-    OSI_VC_CONVERT(aodp)
+    OSI_VC_CONVERT(aodp);
 
-	code = afs_InitReq(&treq, acred);
+    code = afs_InitReq(&treq, acred);
     if (code)
 	return code;
     afs_InitFakeStat(&ofakestate);
